@@ -8,7 +8,8 @@ def u(text, encoding='utf-8'):
     "Return unicode text, no matter what"
 
     if isinstance(text, six.binary_type):
-        return text.decode(encoding)
+        text = text.decode(encoding)
 
     # it's already unicode
+    text = text.replace('\r\n', '\n')
     return text
\ No newline at end of file
